build_cwbvh_from_tris

Function build_cwbvh_from_tris 

pub fn build_cwbvh_from_tris(
    triangles: &[Triangle],
    config: BvhBuildParams,
    core_build_time: &mut Duration,
) -> CwBvh
Build a cwbvh from the given list of Triangles. Just a helper function / example, feel free to reimplement for your specific use case.

Arguments

  • triangles - A list of Triangles.
  • config - Parameters for configuring the BVH building.
  • core_build_time - The core BVH build time. Does not include things like initial AABB generation or debug validation. This is mostly just here to simplify profiling in tray_racing